@@ -410,12 +410,13 @@ class WebSocket:
                         data = from_dict(data_class=TrackStuck, data=data)
                     case "WebSocketClosedEvent":
                         data = from_dict(data_class=Closed, data=data)
-                    case "SegmentsLoadedEvent":
+                    case "SegmentsLoaded":
                         data = from_dict(data_class=SegmentsLoaded, data=data)
-                    case "SegmentSkippedEvent":
+                    case "SegmentSkipped":
                         data = from_dict(data_class=SegmentSkipped, data=data)
                     case __:
-                        self._logger.warning("Received unknown event: %s", data["type"])
+                        self._logger.warning("Received unknown event: %s - ignoring it", data["type"])
+                        return
                 await self.handle_event(data)
             case "ready":
                 data = from_dict(data_class=Ready, data=data)
@@ -531,9 +532,6 @@ class WebSocket:
         match data.type:
             case "TrackEndEvent":
                 data = typing.cast(TrackEnd, data)
-                if player.current and player.current.encoded == data.encodedTrack:
-                    player.current.timestamp = 0
-
                 event = TrackEndEvent(
                     player,
                     track,
@@ -578,7 +576,6 @@ class WebSocket:
             return
         requester = None
         if player.current and player.current.encoded == data.encodedTrack:
-            player.current.timestamp = 0
             requester = player.current.requester
         return await Track.build_track(
             data=data.encodedTrack,
